==> haskell-retry-0.7.7.0-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-retry.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: retry
version: 0.7.7.0
id: retry-0.7.7.0-psnmdr1WUeKC0Bnkrrr5S
key: retry-0.7.7.0-psnmdr1WUeKC0Bnkrrr5S
license: BSD-3-Clause
copyright: Ozgun Ataman, Soostone Inc
maintainer: ozgun.ataman@soostone.com
author: Ozgun Ataman
homepage: http://github.com/Soostone/retry
synopsis: Retry combinators for monadic actions that may fail
description:
    This package exposes combinators that can wrap arbitrary
    monadic actions. They run the action and potentially retry
    running it with some configurable delay for a configurable
    number of times.
    The purpose is to make it easier to work with IO and
    especially network IO actions that often experience temporary
    failure and warrant retrying of the original action. For
    example, a database query may time out for a while, in which
    case we should hang back for a bit and retry the query instead
    of simply raising an exception.
category: Control
abi: 7d5d87eaffe3ce0a1c5fa891cf84da38
exposed: True
exposed-modules:
    Control.Retry
import-dirs: /usr/lib/ghc-8.4.3/site-local/retry-0.7.7.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/retry-0.7.7.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/retry-0.7.7.0
hs-libraries: HSretry-0.7.7.0-psnmdr1WUeKC0Bnkrrr5S
depends:
    base-4.11.1.0 data-default-class-0.1.2.0-EBMa9CD2M17D2Emy9Sff6j
    exceptions-0.10.0-4E5CMyEcw7c5SGR3xFIeNi ghc-prim-0.5.2.0
    random-1.1-9LLJAJa4iQFLJiLXBOBXBV transformers-0.5.5.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             data-default-class-0.1.2.0-EBMa9CD2M17D2Emy9Sff6j=82e1626338bbe81f5b3354a12d7a2c38
             exceptions-0.10.0-4E5CMyEcw7c5SGR3xFIeNi=b417f0870e3d66d725c431d901a306c8
             ghc-prim-0.5.2.0=387aa7e78e4e6c49e51798e4d6763c3f
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=2cade9e72fa19fe7a43e5ace84505d9f
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
haddock-interfaces: /usr/share/doc/haskell-retry/html/retry.haddock
haddock-html: /usr/share/doc/haskell-retry/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-retry-0.7.7.0-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-retry.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: retry
version: 0.7.7.0
id: retry-0.7.7.0-4SdGdtuvhojHhX1tDMXWO4
key: retry-0.7.7.0-4SdGdtuvhojHhX1tDMXWO4
license: BSD-3-Clause
copyright: Ozgun Ataman, Soostone Inc
maintainer: ozgun.ataman@soostone.com
author: Ozgun Ataman
homepage: http://github.com/Soostone/retry
synopsis: Retry combinators for monadic actions that may fail
description:
    This package exposes combinators that can wrap arbitrary
    monadic actions. They run the action and potentially retry
    running it with some configurable delay for a configurable
    number of times.
    The purpose is to make it easier to work with IO and
    especially network IO actions that often experience temporary
    failure and warrant retrying of the original action. For
    example, a database query may time out for a while, in which
    case we should hang back for a bit and retry the query instead
    of simply raising an exception.
category: Control
abi: 3daa135e8bb2cbac99d41437024adbbc
exposed: True
exposed-modules:
    Control.Retry
import-dirs: /usr/lib/ghc-8.4.3/site-local/retry-0.7.7.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/retry-0.7.7.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/retry-0.7.7.0
hs-libraries: HSretry-0.7.7.0-4SdGdtuvhojHhX1tDMXWO4
depends:
    base-4.11.1.0 data-default-class-0.1.2.0-EBMa9CD2M17D2Emy9Sff6j
    exceptions-0.10.0-4E5CMyEcw7c5SGR3xFIeNi ghc-prim-0.5.2.0
    random-1.1-9LLJAJa4iQFLJiLXBOBXBV transformers-0.5.5.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             data-default-class-0.1.2.0-EBMa9CD2M17D2Emy9Sff6j=82e1626338bbe81f5b3354a12d7a2c38
             exceptions-0.10.0-4E5CMyEcw7c5SGR3xFIeNi=b417f0870e3d66d725c431d901a306c8
             ghc-prim-0.5.2.0=387aa7e78e4e6c49e51798e4d6763c3f
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=2cade9e72fa19fe7a43e5ace84505d9f
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
haddock-interfaces: /usr/share/doc/haskell-retry/html/retry.haddock
haddock-html: /usr/share/doc/haskell-retry/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
